@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import asyncio
 import os
 from typing import Generic, TypeVar, Any
@@ -13,7 +11,7 @@ class Env(Generic[T]):
     def __init__(
         self,
         envar: str,
-        data_type: Env[T],
+        data_type: 'Env[T]',
     ):
         super().__init__()
         self._envar = envar
@@ -39,7 +37,13 @@ class Env(Generic[T]):
     def data_type(self):
         return self._data_types
 
-    async def parse(self, _: str | None = None):
+    async def parse(self, arg: str | None = None):
+        
+        if arg:
+            self.data = arg
+
+            return self
+
         result = await self._load_envar()
         if isinstance(result, Exception):
             return result
