@@ -6,5 +6,7 @@ from .refresh_rate import RefreshRateProfile
 class EngineConfig(BaseModel):
     width: StrictInt | None = None
     height: StrictInt | None = None
+    max_width: StrictInt | None = None
+    max_height: StrictInt | None = None
     refresh_profile: RefreshRateProfile = "medium"
     override_refresh_rate: StrictInt | StrictFloat | None = None
